%define upstream_name    Sys-Virt
%define upstream_version v10.2.0

%{?perl_default_filter}
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}Test::Pod

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 1

Summary:    Interface to libvirt virtual machine management API
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}/
Source0:    https://cpan.metacpan.org/modules/by-module/Sys/%{upstream_name}-%{upstream_version}.tar.gz

# Build

BuildRequires: perl(ExtUtils::CBuilder)
BuildRequires: perl(Module::Build)
BuildRequires: perl(Sys::Hostname)
BuildRequires: perl(Test::CPAN::Changes)
BuildRequires: perl(Test::More)
BuildRequires: perl(Test::Pod)
BuildRequires: perl(Test::Pod::Coverage)
BuildRequires: perl(Time::HiRes)
BuildRequires: perl(XML::XPath)
BuildRequires: perl(XML::XPath::XMLParser)
BuildRequires: pkgconfig(libvirt) >= %{version}
# Tests only
BuildRequires: libvirt-utils >= %{version}
BuildRequires: perl-devel
# Optional tests only

%description
The Sys::Virt module provides a Perl XS binding to the libvirt virtual
machine management APIs. This allows machines running within arbitrary
virtualization containers to be managed with a consistent API.

%package tests
Summary:    Tests for %{name}
Requires:   %{name} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires:   perl-Test-Harness
%description tests
Tests from %{name}-%{version}. Execute them
with "%{_libexecdir}/%{name}/test".

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
# Help file to recognise the Perl scripts and normalize shebangs
for F in t/*.t; do
    if head -1 "$F" | grep -q -e '^#!.*perl' ; then
        perl -MConfig -pi -e 's|^#!.*perl\b|$Config{startperl}|' "$F"
    else
        perl -i -MConfig -ple 'print $Config{startperl} if $. == 1' "$F"
    fi
    chmod +x "$F"
done

# Remove release tests
for F in t/005-pod.t t/010-pod-coverage.t t/015-changes.t; do
    rm "$F"
    perl -i -ne 'print $_ unless m{^\Q'"$F"'\E}' MANIFEST
done

%build
perl Makefile.PL INSTALLDIRS=vendor
make CFLAGS="%{optflags}"

%install
%make_install

# Install tests
mkdir -p %{buildroot}/%{_libexecdir}/%{name}
cp -a t %{buildroot}/%{_libexecdir}/%{name}
cat > %{buildroot}/%{_libexecdir}/%{name}/test << 'EOF'
#!/bin/sh
cd %{_libexecdir}/%{name} && exec prove -I . -j "$(getconf _NPROCESSORS_ONLN)"
EOF
chmod +x %{buildroot}/%{_libexecdir}/%{name}/test

%check
export HARNESS_OPTIONS=j$(perl -e 'if ($ARGV[0] =~ /.*-j([0-9][0-9]*).*/) {print $1} else {print 1}' -- '%{?_smp_mflags}')
make test

%files
%license LICENSE
%doc AUTHORS Changes HACKING INSTALL LICENSE META.json META.yml MYMETA.yml README examples
%{perl_vendorarch}/Sys
%{perl_vendorarch}/auto/Sys
%{_mandir}/man3/Sys::Virt*3pm*

%files tests
%{_libexecdir}/%{name}

%changelog
* Sat May 25 2024 tv <tv> 10.2.0-1.mga10
+ Revision: 2067671
- update to v10.2.0

* Wed Dec 06 2023 tv <tv> 9.8.0-1.mga10
+ Revision: 2013572
- update to v9.8.0

* Mon Sep 18 2023 tv <tv> 9.7.0-1.mga10
+ Revision: 1987667
- update to v9.7.0

* Wed Sep 06 2023 tv <tv> 9.4.0-1.mga10
+ Revision: 1984745
- update to v9.4.0

* Mon Feb 06 2023 tv <tv> 9.0.0-1.mga9
+ Revision: 1938927
- update to v9.0.0

* Wed Dec 14 2022 tv <tv> 8.10.0-1.mga9
+ Revision: 1922075
- update to v8.10.0

* Sat Nov 05 2022 tv <tv> 8.9.0-1.mga9
+ Revision: 1903719
- update to v8.9.0
- update to v8.8.0

* Mon Aug 01 2022 tv <tv> 8.5.0-2.mga9
+ Revision: 1874277
- update to v8.5.0

* Fri Jun 10 2022 tv <tv> 8.4.0-1.mga9
+ Revision: 1863918
- update to v8.4.0

* Thu May 05 2022 tv <tv> 8.3.0-1.mga9
+ Revision: 1856240
- update to v8.3.0

* Tue Apr 05 2022 umeabot <umeabot> 8.1.0-2.mga9
+ Revision: 1844859
- Mageia 9 Mass Rebuild

* Fri Mar 04 2022 tv <tv> 8.1.0-1.mga9
+ Revision: 1788355
- update to v8.1.0

* Wed Jan 19 2022 tv <tv> 8.0.0-1.mga9
+ Revision: 1769107
- Update to version 8.0.0

* Sat Dec 04 2021 tv <tv> 7.10.0-1.mga9
+ Revision: 1760682
- update to v7.10.0

* Wed Nov 03 2021 tv <tv> 7.9.0-1.mga9
+ Revision: 1753833
- update to v7.9.0

* Thu Oct 28 2021 tv <tv> 7.8.0-1.mga9
+ Revision: 1753154
- update to v7.8.0

* Tue Sep 14 2021 tv <tv> 7.7.0-1.mga9
+ Revision: 1745422
- update to v7.7.0

* Mon Jul 05 2021 tv <tv> 7.5.0-1.mga9
+ Revision: 1734868
- update to v7.5.0

* Sun Jun 06 2021 tv <tv> 7.4.0-1.mga9
+ Revision: 1729874
- update to v7.4.0

* Thu May 06 2021 tv <tv> 7.3.0-1.mga9
+ Revision: 1721706
- 7.3.0

* Sun Apr 04 2021 tv <tv> 7.2.0-1.mga9
+ Revision: 1713158
- update to v7.2.0

* Wed Mar 03 2021 tv <tv> 7.1.0-1.mga9
+ Revision: 1696528
- Update to v7.1.0
- Package tests
- Run testsuite
+ guillomovitch <guillomovitch>
- new version 7.1.0

* Thu Feb 25 2021 tv <tv> 7.0.0-1.mga9
+ Revision: 1690370
- update to v7.0.0

* Wed Dec 02 2020 tv <tv> 6.10.0-1.mga8
+ Revision: 1651704
- update to v6.10.0

* Tue Oct 06 2020 tv <tv> 6.8.0-1.mga8
+ Revision: 1632361
- v6.8.0

* Sat Jul 18 2020 tv <tv> 6.3.0-2.mga8
+ Revision: 1606999
- rebuild for perl-5.32 (binary package w/o a dep on libperl.so

* Wed May 06 2020 tv <tv> 6.3.0-1.mga8
+ Revision: 1580936
- update to v6.3.0

* Wed Mar 11 2020 tv <tv> 6.1.0-1.mga8
+ Revision: 1555533
- update to 6.1.0

* Wed Feb 19 2020 umeabot <umeabot> 6.0.0-2.mga8
+ Revision: 1543172
- Mageia 8 Mass Rebuild

* Fri Jan 17 2020 tv <tv> 6.0.0-1.mga8
+ Revision: 1481171
- update to 6.0.0

* Tue Oct 08 2019 tv <tv> 5.8.0-1.mga8
+ Revision: 1450551
- update to 5.8.0

* Fri Sep 06 2019 tv <tv> 5.7.0-1.mga8
+ Revision: 1437905
- update to v5.7.0

* Wed Aug 07 2019 tv <tv> 5.6.0-1.mga8
+ Revision: 1427936
- update to 5.6.0

* Thu Jul 04 2019 tv <tv> 5.5.0-1.mga8
+ Revision: 1418469
- update to v5.5.0

* Mon Jul 01 2019 tv <tv> 5.4.0-1.mga8
+ Revision: 1417215
- update to v5.4.0

* Thu Apr 04 2019 tv <tv> 5.2.0-1.mga7
+ Revision: 1385744
- update to v5.2.0

* Tue Mar 05 2019 tv <tv> 5.1.0-1.mga7
+ Revision: 1371732
- update to v5.1.0

* Fri Jan 25 2019 tv <tv> 5.0.0-1.mga7
+ Revision: 1360630
- update to v5.0.0

* Tue Dec 04 2018 tv <tv> 4.10.0-1.mga7
+ Revision: 1338248
- 4.10.0

* Sun Oct 07 2018 tv <tv> 4.8.0-1.mga7
+ Revision: 1318424
- update to v4.8.0

* Thu Sep 06 2018 tv <tv> 4.7.0-1.mga7
+ Revision: 1257482
- update to v4.7.0

* Thu Aug 09 2018 tv <tv> 4.6.0-1.mga7
+ Revision: 1250647
- update to v4.6.0

* Wed Aug 08 2018 pterjan <pterjan> 4.5.0-2.mga7
+ Revision: 1249278
- Rebuild for perl 5.28

* Thu Jul 05 2018 tv <tv> 4.5.0-1.mga7
+ Revision: 1241737
- update to v4.5.0

* Thu Jun 07 2018 tv <tv> 4.4.0-1.mga7
+ Revision: 1235134
- update to v4.4.0

* Thu Apr 05 2018 tv <tv> 4.2.0-1.mga7
+ Revision: 1215342
- update to 4.2.0

* Fri Mar 09 2018 tv <tv> 4.1.0-1.mga7
+ Revision: 1207862
- update to 4.1.0

* Thu Jan 25 2018 tv <tv> 4.0.0-1.mga7
+ Revision: 1196888
- update to 4.0.0
- update to 4.0.0

* Wed Dec 06 2017 tv <tv> 3.9.1-1.mga7
+ Revision: 1181564
- update to 3.9.1

* Sat Oct 28 2017 tv <tv> 3.8.0-2.mga7
+ Revision: 1174317
- do not require test modules

* Sun Oct 08 2017 tv <tv> 3.8.0-1.mga7
+ Revision: 1170257
- update to 3.8.0

* Tue Oct 03 2017 tv <tv> 3.7.0-2.mga7
+ Revision: 1166682
- rebuild with fixed rpm for missing autodeps

* Sun Sep 10 2017 tv <tv> 3.7.0-1.mga7
+ Revision: 1152486
- new release

* Thu Aug 31 2017 pterjan <pterjan> 3.5.0-2.mga7
+ Revision: 1149933
- Rebuild for perl ABI changes

* Sat Jul 22 2017 shlomif <shlomif> 3.5.0-1.mga7
+ Revision: 1128317
- New version 3.5.0
+ tv <tv>
- rebuild for perl 5.26
+ neoclust <neoclust>
- Rebuild against new Perl 5.26

* Thu Jun 16 2016 tv <tv> 1.3.5-1.mga6
+ Revision: 1021641
- new release
- fix build on arm: drop useless BR on xen-devel

* Wed Jun 15 2016 tv <tv> 1.3.4-2.mga6
+ Revision: 1021548
- we need a newer libvirt
- use %%license

* Sun May 08 2016 shlomif <shlomif> 1.3.4-1.mga6
+ Revision: 1010784
- update to 1.3.4

* Fri Apr 15 2016 shlomif <shlomif> 1.3.3-1.mga6
+ Revision: 1002301
- update to 1.3.3

* Thu Feb 18 2016 umeabot <umeabot> 1.2.21-2.mga6
+ Revision: 966477
- Mageia 6 Mass Rebuild
+ tv <tv>
- new release

* Fri Jun 26 2015 tv <tv> 1.2.8-6.mga6
+ Revision: 845305
- rebuild for soname-ifed perl

* Tue Jun 23 2015 tv <tv> 1.2.8-5.mga6
+ Revision: 841128
- rebuild for perl-5.22

* Sun Oct 19 2014 umeabot <umeabot> 1.2.8-4.mga5
+ Revision: 788721
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 1.2.8-3.mga5
+ Revision: 749162
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.8-2.mga5
+ Revision: 686297
- Mageia 5 Mass Rebuild

* Sat Sep 06 2014 sander85 <sander85> 1.2.8-1.mga5
+ Revision: 672853
- update to 1.2.8

* Sun Jul 27 2014 sander85 <sander85> 1.2.6-1.mga5
+ Revision: 657542
- update to 1.2.6

* Wed Jun 04 2014 sander85 <sander85> 1.2.5-1.mga5
+ Revision: 633038
- update to 1.2.5

* Tue Jun 03 2014 pterjan <pterjan> 1.2.4-2.mga5
+ Revision: 631738
- Rebuild for perl 5.20

* Mon May 19 2014 sander85 <sander85> 1.2.4-1.mga5
+ Revision: 623866
- update to 1.2.4

* Fri Jan 24 2014 oden <oden> 1.2.1-1.mga4
+ Revision: 567706
- 1.2.1

* Mon Oct 21 2013 umeabot <umeabot> 1.1.3-2.mga4
+ Revision: 540788
- Mageia 4 Mass Rebuild

* Wed Oct 09 2013 sander85 <sander85> 1.1.3-1.mga4
+ Revision: 494309
- update to 1.1.3

* Fri Sep 27 2013 sander85 <sander85> 1.1.2-1.mga4
+ Revision: 488048
- update to 1.1.2

* Wed Jul 31 2013 sander85 <sander85> 1.1.1-1.mga4
+ Revision: 461461
- update to 1.1.1

* Mon Jul 29 2013 sander85 <sander85> 1.1.0-1.mga4
+ Revision: 460639
- update to 1.1.0

* Mon Jun 10 2013 jquelin <jquelin> 1.0.5-1.mga4
+ Revision: 441755
- update to 1.0.5

* Wed May 29 2013 jquelin <jquelin> 1.0.0-4.mga4
+ Revision: 432313
- perl 5.18.0 rebuild

* Wed May 29 2013 jquelin <jquelin> 1.0.0-3.mga4
+ Revision: 432155
- perl 5.18.0 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 1.0.0-2.mga3
+ Revision: 373003
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 jquelin <jquelin> 1.0.0-1.mga3
+ Revision: 342644
- update to 1.0.0

* Thu Sep 27 2012 jquelin <jquelin> 0.10.2-1.mga3
+ Revision: 298737
- update to 0.10.2

* Wed May 30 2012 jquelin <jquelin> 0.9.10-2.mga3
+ Revision: 251188
- rebuild for perl 5.16

* Fri Feb 24 2012 jquelin <jquelin> 0.9.10-1.mga2
+ Revision: 213771
- update to 0.9.10

* Wed Jan 25 2012 jquelin <jquelin> 0.9.9-1.mga2
+ Revision: 201022
- update to 0.9.9

* Thu Jan 05 2012 jquelin <jquelin> 0.9.8-1.mga2
+ Revision: 191286
- update to 0.9.8

* Thu Dec 08 2011 kharec <kharec> 0.9.7-1.mga2
+ Revision: 179276
- update to 0.9.7

* Fri Oct 14 2011 jquelin <jquelin> 0.9.5-1.mga2
+ Revision: 154847
- update to 0.9.5
- update to 0.9.3
+ fwang <fwang>
- new version 0.9.4

* Wed Jul 13 2011 jquelin <jquelin> 0.9.2-1.mga2
+ Revision: 123641
- update to 0.9.2

* Fri Jul 08 2011 jquelin <jquelin> 0.2.8-1.mga2
+ Revision: 120630
- update to 0.2.8

* Sun Jun 12 2011 sander85 <sander85> 0.2.6-2.mga2
+ Revision: 105009
- Rebuild for perl 5.14

* Tue Mar 15 2011 saispo <saispo> 0.2.6-1.mga1
+ Revision: 72040
- Disable test
- New release 0.2.6
+ jquelin <jquelin>
- mageia rebuild
- imported package perl-Sys-Virt

